@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2022 Savoir-faire Linux Inc.
+ *  Copyright (C) 2014-2023 Savoir-faire Linux Inc.
  *  Authors: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *           Simon Désaulniers <simon.desaulniers@savoirfairelinux.com>
  *           Sébastien Blin <sebastien.blin@savoirfairelinux.com>
@@ -25,7 +25,7 @@
 #include "value.h"
 #include "callbacks.h"
 #include "sockaddr.h"
-#include "log_enable.h"
+#include "logger.h"
 #include "network_utils.h"
 #include "node_export.h"
 
@@ -78,6 +78,8 @@ public:
         StatusCallback statusChangedCallback {};
         CertificateStoreQuery certificateStore {};
         IdentityAnnouncedCb identityAnnouncedCb {};
+        PublicAddressChangedCb publicAddressChangedCb {};
+        std::unique_ptr<std::mt19937_64> rng {};
         Context() {}
     };
 
@@ -349,7 +351,6 @@ public:
     void setLogger(const Logger& logger) {
         setLogger(std::make_shared<Logger>(logger));
     }
-    void setLoggers(LogMethod err = {}, LogMethod warn = {}, LogMethod debug = {});
 
     /**
      * Only print logs related to the given InfoHash (if given), or disable filter (if zeroes).
@@ -408,7 +409,8 @@ public:
     void run(const Config& config, Context&& context);
 
     void setOnStatusChanged(StatusCallback&& cb) {
-        statusCb = std::move(cb);
+        if (cb)
+            statusCbs.emplace_back(std::move(cb));
     }
 
     /**
@@ -518,7 +520,8 @@ private:
 
     NodeStatus status4 {NodeStatus::Disconnected},
                status6 {NodeStatus::Disconnected};
-    StatusCallback statusCb {nullptr};
+
+    std::vector<StatusCallback> statusCbs {};
 
     /** PeerDiscovery Parameters */
     std::shared_ptr<PeerDiscovery> peerDiscovery_;
